const debug = process.env.NODE_ENV !== 'production';
const webpack = require('webpack');
const CompressionPlugin = require('compression-webpack-plugin');

console.log(`Running webpack in ${debug ? 'development' : 'production'} mode.`);

module.exports = {
	devtool: 'cheap-module-source-map', // 'source-map',
	context: __dirname,
	//	devtool: debug ? "inline-sourcemap" : null,
	entry: './index.js',
	module: {
		loaders: [
			{
				test: /\.css$/,
				use: ['style-loader', 'css-loader']
			},
			{
				test: /\.jsx?$/,
				exclude: /(node_modules|bower_components)/,
				loader: 'babel-loader',
				query: {
					presets: ['es2015']
				}
			}
		]
	},
	output: {
		path: __dirname + '/dist/',
		filename: 'carousel.min.js'
	},
	plugins: debug
		? []
		: [
				new webpack.DefinePlugin({
					'process.env': {
						NODE_ENV: JSON.stringify('production')
					}
				}),
				new webpack.optimize.OccurrenceOrderPlugin(),
				new webpack.optimize.UglifyJsPlugin({
					mangle: false,
					beautify: false,
					sourcemap: false,
					comments: false,
					minimize: true,
					compress: {
						warnings: false,
						// Disabled because of an issue with Uglify breaking seemingly valid code:
						// https://github.com/facebookincubator/create-react-app/issues/2376
						// Pending further investigation:
						// https://github.com/mishoo/UglifyJS2/issues/2011
						comparisons: false
					},
					output: {
						comments: false,
						// Turned on because emoji and regex is not minified properly using default
						// https://github.com/facebookincubator/create-react-app/issues/2488
						ascii_only: true
					}
				}),
				new CompressionPlugin({
					asset: '[path].gz[query]',
					algorithm: 'gzip',
					test: /\.(js|css)$/,
					threshold: 10240,
					minRatio: 0.8
				})
			]
};
